Module speedrunapi::user_data

source ·
Users

Handles user requests and returing the user data.

What are users anyways? Users are the people on speedrun.com that have an account. This account then can submit runs and chat in fourms on the website.

Users have different data points assosiated with them

You can use the functions in this module to get differnt parts and peices of the data or the whole set!

Structs

Enums